emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r107321: Use utf-8 Baha'i in calendar


From: Glenn Morris
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r107321: Use utf-8 Baha'i in calendar doc-strings, menus, etc
Date: Fri, 17 Feb 2012 22:08:15 -0500
User-agent: Bazaar (2.3.1)

------------------------------------------------------------
revno: 107321
committer: Glenn Morris <address@hidden>
branch nick: trunk
timestamp: Fri 2012-02-17 22:08:15 -0500
message:
  Use utf-8 Baha'i in calendar doc-strings, menus, etc
  
  * lisp/calendar/cal-menu.el (cal-menu-diary-menu, cal-menu-goto-menu):
  * lisp/calendar/calendar.el (diary-file, diary-bahai-entry-symbol)
  (calendar-bahai-all-holidays-flag, calendar-other-dates):
  * lisp/calendar/diary-lib.el (diary-abbreviated-year-flag):
  * lisp/calendar/holidays.el (holiday-bahai-holidays)
  (calendar-holidays, list-holidays):
  Use utf-8 Baha'i in doc-strings, menus, etc.
modified:
  lisp/ChangeLog
  lisp/calendar/cal-menu.el
  lisp/calendar/calendar.el
  lisp/calendar/diary-lib.el
  lisp/calendar/holidays.el
=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog    2012-02-17 20:19:30 +0000
+++ b/lisp/ChangeLog    2012-02-18 03:08:15 +0000
@@ -1,3 +1,13 @@
+2012-02-18  Glenn Morris  <address@hidden>
+
+       * calendar/cal-menu.el (cal-menu-diary-menu, cal-menu-goto-menu):
+       * calendar/calendar.el (diary-file, diary-bahai-entry-symbol)
+       (calendar-bahai-all-holidays-flag, calendar-other-dates):
+       * calendar/diary-lib.el (diary-abbreviated-year-flag):
+       * calendar/holidays.el (holiday-bahai-holidays)
+       (calendar-holidays, list-holidays):
+       Use utf-8 Bahá'í in doc-strings, menus, etc.
+
 2012-02-17  Tassilo Horn  <address@hidden>
 
        * saveplace.el (save-place-ignore-files-regexp): New variable

=== modified file 'lisp/calendar/cal-menu.el'
--- a/lisp/calendar/cal-menu.el 2012-01-19 07:21:25 +0000
+++ b/lisp/calendar/cal-menu.el 2012-02-18 03:08:15 +0000
@@ -52,7 +52,7 @@
     ["Insert Anniversary" diary-insert-anniversary-entry]
     ["Insert Block" diary-insert-block-entry]
     ["Insert Cyclic" diary-insert-cyclic-entry]
-    ("Insert Baha'i"
+    ("Insert Bahá'í"
      ["One time" diary-bahai-insert-entry]
      ["Monthly" diary-bahai-insert-monthly-entry]
      ["Yearly" diary-bahai-insert-yearly-entry])
@@ -127,7 +127,7 @@
     ["Astronomical Date" calendar-astro-goto-day-number]
     ["Hebrew Date" calendar-hebrew-goto-date]
     ["Persian Date" calendar-persian-goto-date]
-    ["Baha'i Date" calendar-bahai-goto-date]
+    ["Bahá'í Date" calendar-bahai-goto-date]
     ["Islamic Date" calendar-islamic-goto-date]
     ["Julian Date" calendar-julian-goto-date]
     ["Chinese Date" calendar-chinese-goto-date]
@@ -282,4 +282,8 @@
 
 (provide 'cal-menu)
 
+;; Local Variables:
+;; coding: utf-8
+;; End:
+
 ;;; cal-menu.el ends here

=== modified file 'lisp/calendar/calendar.el'
--- a/lisp/calendar/diary-lib.el        2012-01-19 07:21:25 +0000
+++ b/lisp/calendar/diary-lib.el        2012-02-18 03:08:15 +0000
@@ -337,7 +337,7 @@
 
 (defcustom diary-abbreviated-year-flag t
   "Interpret a two-digit year DD in a diary entry as either 19DD or 20DD.
-This applies to the Gregorian, Hebrew, Islamic, and Baha'i calendars.
+This applies to the Gregorian, Hebrew, Islamic, and Bahá'í calendars.
 When the current century is added to a two-digit year, if the result
 is more than 50 years in the future, the previous century is assumed.
 If the result is more than 50 years in the past, the next century is assumed.
@@ -2624,4 +2624,8 @@
 
 (provide 'diary-lib)
 
+;; Local Variables:
+;; coding: utf-8
+;; End:
+
 ;;; diary-lib.el ends here

=== modified file 'lisp/calendar/holidays.el'
--- a/lisp/calendar/holidays.el 2012-01-19 07:21:25 +0000
+++ b/lisp/calendar/holidays.el 2012-02-18 03:08:15 +0000
@@ -292,16 +292,16 @@
   (mapcar 'purecopy
   '((holiday-bahai-new-year)
     (holiday-bahai-ridvan)      ; respects calendar-bahai-all-holidays-flag
-    (holiday-fixed  5 23 "Declaration of the Bab")
-    (holiday-fixed  5 29 "Ascension of Baha'u'llah")
-    (holiday-fixed  7  9 "Martyrdom of the Bab")
-    (holiday-fixed 10 20 "Birth of the Bab")
-    (holiday-fixed 11 12 "Birth of Baha'u'llah")
+    (holiday-fixed  5 23 "Declaration of the Báb")
+    (holiday-fixed  5 29 "Ascension of Bahá'u'lláh")
+    (holiday-fixed  7  9 "Martyrdom of the Báb")
+    (holiday-fixed 10 20 "Birth of the Báb")
+    (holiday-fixed 11 12 "Birth of Bahá'u'lláh")
     (if calendar-bahai-all-holidays-flag
         (append
          (holiday-fixed 11 26 "Day of the Covenant")
-         (holiday-fixed 11 28 "Ascension of `Abdu'l-Baha")))))
-  "Baha'i holidays.
+         (holiday-fixed 11 28 "Ascension of `Abdu'l-Bahá")))))
+  "Bahá'í holidays.
 See the documentation for `calendar-holidays' for details."
   :type 'sexp
   :group 'holidays)
@@ -376,7 +376,7 @@
                                K>0, and MONTH's last day otherwise.
     (holiday-hebrew MONTH DAY STRING)  a fixed date on the Hebrew calendar
     (holiday-islamic MONTH DAY STRING) a fixed date on the Islamic calendar
-    (holiday-bahai MONTH DAY STRING)   a fixed date on the Baha'i calendar
+    (holiday-bahai MONTH DAY STRING)   a fixed date on the Bahá'í calendar
     (holiday-julian MONTH DAY STRING)  a fixed date on the Julian calendar
     (holiday-sexp SEXP STRING) SEXP is a Gregorian-date-valued expression
                                in the variable `year'; if it evaluates to
@@ -404,11 +404,11 @@
      (holiday-islamic 3 12 \"Mohammed's Birthday\")
 
 since the Islamic months are numbered from 1 starting with Muharram.
-To add an entry for the Baha'i festival of Ridvan, use
+To add an entry for the Bahá'í festival of Ridvan, use
 
      (holiday-bahai 2 13 \"Festival of Ridvan\")
 
-since the Baha'i months are numbered from 1 starting with Baha.
+since the Bahá'í months are numbered from 1 starting with Bahá.
 To add Thomas Jefferson's birthday, April 2, 1743 (Julian), use
 
      (holiday-julian 4 2 \"Jefferson's Birthday\")
@@ -582,7 +582,7 @@
             (if holiday-islamic-holidays
                 (cons "Islamic" holiday-islamic-holidays))
             (if holiday-bahai-holidays
-                (cons "Baha'i" holiday-bahai-holidays))
+                (cons "Bahá'í" holiday-bahai-holidays))
             (if holiday-oriental-holidays
                 (cons "Oriental" holiday-oriental-holidays))
             (if holiday-solar-holidays
@@ -920,4 +920,8 @@
 
 (provide 'holidays)
 
+;; Local Variables:
+;; coding: utf-8
+;; End:
+
 ;;; holidays.el ends here


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- a/lisp/calendar/calendar.el 2012-01-19 07:21:25 +0000
+++ b/lisp/calendar/calendar.el 2012-02-18 03:08:15 +0000
@@ -41,7 +41,7 @@
 ;; can be translated from the (usual) Gregorian calendar to the day of
 ;; the year/days remaining in year, to the ISO commercial calendar, to
 ;; the Julian (old style) calendar, to the Hebrew calendar, to the
 ;; Islamic calendar, to the Baha'i calendar, to the French
 ;; Revolutionary calendar, to the Mayan calendar, to the Chinese
 ;; calendar, to the Coptic calendar, to the Ethiopic calendar, and to
 ;; the astronomical (Julian) day number.  Times of sunrise/sunset can
@@ -52,7 +52,7 @@
 ;; The following files are part of the calendar/diary code:
 
 ;;    appt.el                    Appointment notification
-;;    cal-bahai.el               Baha'i calendar
+;;    cal-bahai.el               Bahá'í calendar
 ;;    cal-china.el               Chinese calendar
 ;;    cal-coptic.el              Coptic/Ethiopic calendars
 ;;    cal-dst.el                 Daylight saving time rules
@@ -642,7 +642,7 @@
 November 10, 1990.  See the documentation for the function
 `diary-list-sexp-entries' for more details.
 
-Diary entries based on the Hebrew, the Islamic and/or the Baha'i
+Diary entries based on the Hebrew, the Islamic and/or the Bahá'í
 calendar are also possible, but because these are somewhat slow, they
 are ignored unless you set the `diary-nongregorian-listing-hook' and
 the `diary-nongregorian-marking-hook' appropriately.  See the
@@ -679,7 +679,7 @@
   'diary-bahai-entry-symbol "23.1")
 
 (defcustom diary-bahai-entry-symbol "B"
-  "Symbol indicating a diary entry according to the Baha'i calendar."
+  "Symbol indicating a diary entry according to the Bahá'í calendar."
   :type 'string
   :group 'diary)
 
@@ -1005,9 +1005,9 @@
   'calendar-bahai-all-holidays-flag "23.1")
 
 (defcustom calendar-bahai-all-holidays-flag nil
-  "If nil, show only major holidays from the Baha'i calendar.
+  "If nil, show only major holidays from the Bahá'í calendar.
 These are the days on which work and school must be suspended.
-Otherwise, show all the holidays that would appear in a complete Baha'i
+Otherwise, show all the holidays that would appear in a complete Bahá'í
 calendar."
   :type 'boolean
   :group 'holidays)
@@ -2552,7 +2552,7 @@
            (unless (string-equal
                     (setq odate (calendar-bahai-date-string date))
                     "")
-             (format "Baha'i date: %s" odate))
+             (format "Bahá'í date: %s" odate))
            (format "Chinese date: %s"
                    (calendar-chinese-date-string date))
            (unless (string-equal
@@ -2624,6 +2624,7 @@
 
 ;; Local variables:
 ;; byte-compile-dynamic: t
+;; coding: utf-8
 ;; End:
 
 ;;; calendar.el ends here
@@ -41,7 +41,7 @@
 ;; the year/days remaining in year, to the ISO commercial calendar, to
 ;; the Julian (old style) calendar, to the Hebrew calendar, to the
-;; Islamic calendar, to the Baha'i calendar, to the French
+;; Islamic calendar, to the Bahá'í calendar, to the French
 ;; Revolutionary calendar, to the Mayan calendar, to the Chinese
 ;; calendar, to the Coptic calendar, to the Ethiopic calendar, and to

=== modified file 'lisp/calendar/diary-lib.el'